/*******************************************************************************
 * Copyright (c) 2000, 2006 Eteration A.S. and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     Eteration A.S. - initial API and implementation
 *******************************************************************************/

package org.eclipse.wtp.releng.monitor;

import java.util.Properties;
import java.util.StringTokenizer;

import javax.mail.Address;
import javax.mail.MessagingException;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.internet.AddressException;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;

public class WtpMailer {

	private Address[] getAddresses() {
		int i = 0;
		StringTokenizer recipients = new StringTokenizer(recipientsList, ",");
		Address addresses[] = new Address[recipients.countTokens()];
		while (recipients.hasMoreTokens())
			try {
				addresses[i++] = new InternetAddress(recipients.nextToken());
			} catch (AddressException e) {
				System.out.println("Unable to create address");
			}
		return addresses;
	}

	public WtpMailer(String host, String sender, String recpst, String prefix,
			String buildLabel, String buildLink) {
		sendMail = true;
		this.host = "127.0.0.1";
		from = "";
		recipientsList = "";
		this.prefix = "";
		this.buildLabel = "";
		this.buildLink = "";
		if (host == null || host.length() == 0 || host.indexOf(" ") >= 0)
			sendMail = false;
		this.host = host;
		from = sender;
		recipientsList = recpst;
		this.prefix = prefix;
		this.buildLabel = buildLabel;
		this.buildLink = buildLink;
	}

	public void sendMessage(String aSubject, String aMessage) {
		if (aSubject == null || aMessage == null || !sendMail)
			printEmailFailureNotice(aSubject, aMessage);
		Properties props = System.getProperties();
		props.put("mail.smtp.host", host);
		Session session = Session.getDefaultInstance(props);
		MimeMessage message = new MimeMessage(session);
		try {
			message.setFrom(new InternetAddress(from));
			message.addRecipients(javax.mail.Message.RecipientType.TO,
					getAddresses());
			message.setSubject(prefix + "[" + buildLabel + "] - " + aSubject);
			message.setContent("<a href=\"" + buildLink
					+ "\">Build is ready at: " + buildLink + "</a>\n\n"
					+ aMessage, "text/html");
			Transport.send(message);
		} catch (AddressException e) {
			e.printStackTrace();
		} catch (MessagingException e) {
			e.printStackTrace();
		}
	}

	private void printEmailFailureNotice(String aSubject, String aMessage) {
		System.out.println("Email failed.  Settings:");
		System.out.println("\nhost=" + host + "\nsender=" + from
				+ "\nrecipients=" + recipientsList);
		System.out.println("\nSubject=" + aSubject + "\nMessage=" + aMessage);
	}

	boolean sendMail;

	String host;

	String from;

	String recipientsList;

	String prefix;

	String buildLabel;

	String buildLink;
}
